# dwipy

[![Build Status](https://github.com/svdvoort/dwipy/workflows/test/badge.svg?branch=master&event=push)](https://github.com/svdvoort/dwipy/actions?query=workflow%3Atest)
[![Python Version](https://img.shields.io/pypi/pyversions/dwipy.svg)](https://pypi.org/project/dwipy/)
[![wemake-python-styleguide](https://img.shields.io/badge/style-wemake-000000.svg)](https://github.com/wemake-services/wemake-python-styleguide)

DWI analysis pipeline

Made for  the initial analysis of diffusion data, especially for extracting the b-values and b-vectors from DICOM data, to allow for further processing.

## Installation

This package requires the installation of Tesseract 4.1.1: https://medium.com/quantrium-tech/installing-tesseract-4-on-ubuntu-18-04-b6fcd0cbd78f
And mtrix: https://mrtrix.readthedocs.io/en/latest/

```bash
pip install dwipy
```
